@@ -63,13 +63,16 @@ ArchInputDialog::ArchInputDialog(FXWindow* win, FXString inp) :
     option_tgz = new FXOption(popup, _("tar.gz\tArchive format is tar.gz"), NULL, this, ID_FORMAT_TAR_GZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_zip = new FXOption(popup, _("zip\tArchive format is zip"), NULL, this, ID_FORMAT_ZIP, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_7zip = new FXOption(popup, _("7z\tArchive format is 7z"), NULL, this, ID_FORMAT_7ZIP, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_rar = new FXOption(popup, _("rar\tArchive format is rar"), NULL, this, ID_FORMAT_RAR, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_tbz2 = new FXOption(popup, _("tar.bz2\tArchive format is tar.bz2"), NULL, this, ID_FORMAT_TAR_BZ2, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_txz = new FXOption(popup, _("tar.xz\tArchive format is tar.xz"), NULL, this, ID_FORMAT_TAR_XZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_tzst = new FXOption(popup, _("tar.zst\tArchive format is tar.zst"), NULL, this, ID_FORMAT_TAR_ZST, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_tar = new FXOption(popup, _("tar\tArchive format is tar"), NULL, this, ID_FORMAT_TAR, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_taz = new FXOption(popup, _("tar.Z\tArchive format is tar.Z"), NULL, this, ID_FORMAT_TAR_Z, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_gz = new FXOption(popup, _("gz\tArchive format is gz"), NULL, this, ID_FORMAT_GZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_bz2 = new FXOption(popup, _("bz2\tArchive format is bz2"), NULL, this, ID_FORMAT_BZ2, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_xz = new FXOption(popup, _("xz\tArchive format is xz"), NULL, this, ID_FORMAT_XZ, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
+    option_zst = new FXOption(popup, _("zst\tArchive format is zst"), NULL, this, ID_FORMAT_ZST, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     option_z = new FXOption(popup, _("Z\tArchive format is Z"), NULL, this, ID_FORMAT_Z, JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
     optionmenu = new FXOptionMenu(matrix4, popup, LAYOUT_TOP | FRAME_RAISED | FRAME_THICK | JUSTIFY_HZ_APART | ICON_AFTER_TEXT);
 }
@@ -151,7 +154,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if (ext2 == "tar.bz2" || ext2 == "tar.zst")
         {
             str = str.left(str.length() - 8);
             str = str + ".tar.gz";
@@ -169,19 +172,20 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".tar.gz";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".tar.gz";
             input->setText(str);
         }
-        else if ((ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "zst")
+              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.gz";
             input->setText(str);
         }
-        else if ((ext1 == "xz") || (ext1 == "7z") || (ext1 == "gz"))
+        else if ((ext1 == "gz") || (ext1 == "7z") || (ext1 == "xz"))
         {
             str = str.left(str.length() - 3);
             str = str + ".tar.gz";
@@ -207,6 +211,12 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
+        else if (ext2 == "tar.zst")
+        {
+            str = str.left(str.length() - 8);
+            str = str + ".tar.bz2";
+            input->setText(str);
+        }
         else if ((ext2 == "tar.gz") || (ext2 == "tar.xz"))
         {
             str = str.left(str.length() - 7);
@@ -219,7 +229,14 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".tar.bz2";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "tar") || (ext1 == "zip"))
+        else if (ext1 == "tzst")
+        {
+            str = str.left(str.length() - 5);
+            str = str + ".tar.bz2";
+            input->setText(str);
+        }
+        else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "zst")
+              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.bz2";
@@ -251,7 +268,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if (ext2 == "tar.bz2" || ext2 == "tar.zst")
         {
             str = str.left(str.length() - 8);
             str = str + ".tar.xz";
@@ -269,7 +286,14 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".tar.xz";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "bz2") || (ext1 == "taz") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
+        {
+            str = str.left(str.length() - 5);
+            str = str + ".tar.xz";
+            input->setText(str);
+        }
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "zst")
+              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.xz";
@@ -294,14 +318,72 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         }
     }
 
-    else if (FXSELID(sel) == ID_FORMAT_TAR)
+    else if (FXSELID(sel) == ID_FORMAT_TAR_ZST)
     {
         // Handle different archive formats
-        if ((ext1 == "tar") && (ext2 != "tar.gz") && (ext2 != "tar.bz2") && (ext2 != "tar.z") && (ext2 != "tar.xz"))
+        if ((ext2 == "tar.zst") || (ext1 == "tzst"))
         {
             input->setText(str);
         }
         else if (ext2 == "tar.bz2")
+        {
+            str = str.left(str.length() - 8);
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+        else if (ext2 == "tar.gz")
+        {
+            str = str.left(str.length() - 7);
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+        else if (ext2 == "tar.z")
+        {
+            str = str.left(str.length() - 6);
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+        else if (ext1 == "tbz2")
+        {
+            str = str.left(str.length() - 5);
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+        {
+            str = str.left(str.length() - 4);
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+        else if ((ext1 == "gz") || (ext1 == "7z") || (ext1 == "xz"))
+        {
+            str = str.left(str.length() - 3);
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+        else if (ext1 == "z")
+        {
+            str = str.left(str.length() - 2);
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+        else
+        {
+            str = str + ".tar.zst";
+            input->setText(str);
+        }
+    }
+
+    else if (FXSELID(sel) == ID_FORMAT_TAR)
+    {
+        // Handle different archive formats
+        if ((ext1 == "tar") && (ext2 != "tar.gz") && (ext2 != "tar.bz2") && (ext2 != "tar.z")
+         && (ext2 != "tar.xz") && (ext2 != "tar.zst"))
+        {
+            input->setText(str);
+        }
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".tar";
@@ -319,13 +401,14 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".tar";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".tar";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "zip"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar";
@@ -357,7 +440,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".tar.Z";
@@ -369,13 +452,14 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".tar.Z";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".tar.Z";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "bz2") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "bz2") || (ext1 == "zst")
+              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".tar.Z";
@@ -407,7 +491,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".gz";
@@ -425,19 +509,20 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".gz";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".gz";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".gz";
             input->setText(str);
         }
-        else if ((ext1 == "xz") || (ext1 == "7z"))
+        else if ((ext1 == "7z") || (ext1 == "xz"))
         {
             str = str.left(str.length() - 3);
             str = str + ".gz";
@@ -463,7 +548,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".xz";
@@ -481,19 +566,20 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".xz";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".xz";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".xz";
             input->setText(str);
         }
-        else if (ext1 == "7z")
+        else if ((ext1 == "gz") || (ext1 == "7z"))
         {
             str = str.left(str.length() - 3);
             str = str + ".xz";
@@ -520,7 +606,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str.left(str.length() - 8);
             input->setText(str);
         }
-        if (ext2 == "tar.bz2")
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".bz2";
@@ -538,19 +624,20 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".bz2";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".bz2";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "zst")
+              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".bz2";
             input->setText(str);
         }
-        else if ((ext1 == "gz") || (ext1 == "xz") || (ext1 == "7z"))
+        else if ((ext1 == "gz") || (ext1 == "7z") || (ext1 == "xz"))
         {
             str = str.left(str.length() - 3);
             str = str + ".bz2";
@@ -569,6 +656,64 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         }
     }
 
+    else if (FXSELID(sel) == ID_FORMAT_ZST)
+    {
+        // Handle different archive formats
+        if ((ext1 == "zst") && (ext2 != "tar.zst"))
+        {
+            str = str.left(str.length() - 8);
+            input->setText(str);
+        }
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
+        {
+            str = str.left(str.length() - 8);
+            str = str + ".zst";
+            input->setText(str);
+        }
+        else if ((ext2 == "tar.gz") || (ext2 == "tar.xz"))
+        {
+            str = str.left(str.length() - 7);
+            str = str + ".zst";
+            input->setText(str);
+        }
+        else if (ext2 == "tar.z")
+        {
+            str = str.left(str.length() - 6);
+            str = str + ".zst";
+            input->setText(str);
+        }
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
+        {
+            str = str.left(str.length() - 5);
+            str = str + ".zst";
+            input->setText(str);
+        }
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
+        {
+            str = str.left(str.length() - 4);
+            str = str + ".zst";
+            input->setText(str);
+        }
+        else if ((ext1 == "gz") || (ext1 == "7z") || (ext1 == "xz"))
+        {
+            str = str.left(str.length() - 3);
+            str = str + ".zst";
+            input->setText(str);
+        }
+        else if (ext1 == "z")
+        {
+            str = str.left(str.length() - 2);
+            str = str + ".zst";
+            input->setText(str);
+        }
+        else
+        {
+            str = str + ".zst";
+            input->setText(str);
+        }
+    }
+
     else if (FXSELID(sel) == ID_FORMAT_Z)
     {
         // Handle different archive formats
@@ -576,7 +721,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".Z";
@@ -594,13 +739,14 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".Z";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".Z";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "bz2") || (ext1 == "taz") || (ext1 == "txz") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".Z";
@@ -626,7 +772,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".zip";
@@ -644,13 +790,14 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".zip";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".zip";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "bz2") || (ext1 == "taz") || (ext1 == "txz") || (ext1 == "tar"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".zip";
@@ -682,7 +829,7 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
         {
             input->setText(str);
         }
-        else if (ext2 == "tar.bz2")
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
         {
             str = str.left(str.length() - 8);
             str = str + ".7z";
@@ -700,13 +847,14 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             str = str + ".7z";
             input->setText(str);
         }
-        else if ((ext1 == "tbz2") || (ext1 == "tbz"))
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
         {
             str = str.left(str.length() - 5);
             str = str + ".7z";
             input->setText(str);
         }
-        else if ((ext1 == "tgz") || (ext1 == "bz2") || (ext1 == "taz") || (ext1 == "txz") || (ext1 == "tar") || (ext1 == "zip"))
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip") || (ext1 == "rar"))
         {
             str = str.left(str.length() - 4);
             str = str + ".7z";
@@ -730,6 +878,63 @@ long ArchInputDialog::onCmdOption(FXObject*, FXSelector sel, void*)
             input->setText(str);
         }
     }
+    
+    else if (FXSELID(sel) == ID_FORMAT_RAR)
+    {
+        // Handle different archive formats
+        if (ext1 == "rar")
+        {
+            input->setText(str);
+        }
+        else if ((ext2 == "tar.bz2") || (ext2 == "tar.zst"))
+        {
+            str = str.left(str.length() - 8);
+            str = str + ".rar";
+            input->setText(str);
+        }
+        else if ((ext2 == "tar.gz") || (ext2 == "tar.xz"))
+        {
+            str = str.left(str.length() - 7);
+            str = str + ".rar";
+            input->setText(str);
+        }
+        else if (ext2 == "tar.z")
+        {
+            str = str.left(str.length() - 6);
+            str = str + ".rar";
+            input->setText(str);
+        }
+        else if ((ext1 == "tbz2") || (ext1 == "tzst"))
+        {
+            str = str.left(str.length() - 5);
+            str = str + ".rar";
+            input->setText(str);
+        }
+        else if ((ext1 == "tgz") || (ext1 == "tbz") || (ext1 == "txz") || (ext1 == "taz") || (ext1 == "bz2")
+              || (ext1 == "zst") || (ext1 == "tar") || (ext1 == "zip"))
+        {
+            str = str.left(str.length() - 4);
+            str = str + ".rar";
+            input->setText(str);
+        }
+        else if ((ext1 == "gz") || (ext1 == "xz"))
+        {
+            str = str.left(str.length() - 3);
+            str = str + ".rar";
+            input->setText(str);
+        }
+        else if (ext1 == "z")
+        {
+            str = str.left(str.length() - 2);
+            str = str + ".rar";
+            input->setText(str);
+        }
+        else
+        {
+            str = str + ".rar";
+            input->setText(str);
+        }
+    }
 
     return(1);
 }
@@ -756,6 +961,10 @@ long ArchInputDialog::onUpdOption(FXObject*, FXSelector sel, void*)
     {
         optionmenu->setCurrent(option_txz);
     }
+    else if ((ext2 == "tar.zst") || (ext1 == "tzst"))
+    {
+        optionmenu->setCurrent(option_tzst);
+    }
     else if ((ext2 == "tar.z") || (ext1 == "taz"))
     {
         optionmenu->setCurrent(option_taz);
@@ -772,6 +981,10 @@ long ArchInputDialog::onUpdOption(FXObject*, FXSelector sel, void*)
     {
         optionmenu->setCurrent(option_bz2);
     }
+    else if (ext1 == "zst")
+    {
+        optionmenu->setCurrent(option_zst);
+    }
     else if (ext1 == "xz")
     {
         optionmenu->setCurrent(option_xz);
@@ -788,6 +1001,10 @@ long ArchInputDialog::onUpdOption(FXObject*, FXSelector sel, void*)
     {
         optionmenu->setCurrent(option_7zip);
     }
+    else if (ext1 == "rar")
+    {
+        optionmenu->setCurrent(option_rar);
+    }
     else
     {
         optionmenu->setCurrent(option_tgz);
