@@ -150,7 +150,7 @@ DirList::DirList(FXWindow* focuswin, FXComposite* p, FXObject* tgt, FXSelector s
                     {
                         fsdevices->insert(mnt->mnt_dir, "zip");
                     }
-                    else if (streq(mnt->mnt_type, "nfs"))
+                    else if (strncmp(mnt->mnt_type, "nfs", 3))
                     {
                         fsdevices->insert(mnt->mnt_dir, "nfsdisk");
                     }
@@ -2033,8 +2033,8 @@ fnd:
             if (islink)
             {
                 type = _("Link to Folder");
-                item->closedIcon = minilinkicon;
-                item->openIcon = minilinkicon;
+                item->closedIcon = minifolderlinkicon;
+                item->openIcon = minifolderlinkicon;
             }
 
             // Data used to update the tooltip
