@@ -321,7 +321,7 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
             FXulong dirsize = 0;
             FXuint nbfiles = 0, nbsubfolders = 0;
             FXulong totalsize = 0;
-            strlcpy(buf, srcpath.text(), srcpath.length() + 1);
+            strlcpy_(buf, srcpath.text(), srcpath.length() + 1);
             dirsize = pathsize(buf, &nbfiles, &nbsubfolders, &totalsize);
 #if __WORDSIZE == 64
             snprintf(buf, sizeof(buf), "%lu", dirsize);
@@ -351,8 +351,7 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
             FXulong dirsize = 0;
             FXuint nbfiles = 0, nbsubfolders = 0;
             FXulong totalsize = 0;
-
-            strlcpy(buf, tgtpath.text(), tgtpath.length() + 1);
+            strlcpy_(buf, tgtpath.text(), tgtpath.length() + 1);
             dirsize = pathsize(buf, &nbfiles, &nbsubfolders, &totalsize);
 #if __WORDSIZE == 64
             snprintf(buf, sizeof(buf), "%lu", dirsize);
@@ -1384,7 +1383,7 @@ int File::move(const FXString& source, const FXString& target, const FXbool rest
         {
             FXuint nbfiles = 0, nbsubfolders = 0;
             FXulong totalsize = 0;
-            strlcpy(buf, source.text(), source.length() + 1);
+            strlcpy_(buf, source.text(), source.length() + 1);
             srcsize = pathsize(buf, &nbfiles, &nbsubfolders, &totalsize);
             totaldata += srcsize;
         }
@@ -1590,8 +1589,8 @@ int File::chmod(char* path, char* file, mode_t mode, FXbool rec, const FXbool di
 {
     struct stat linfo;
 
-    // Initialise the file variable with the initial path
-    strlcpy(file, path, strlen(path) + 1);
+    // Initialize the file variable with the initial path
+    strlcpy_(file, path, strlen(path) + 1);
 
     // If it doesn't exist
     if (lstatrep(path, &linfo))
@@ -1683,7 +1682,7 @@ int File::rchmod(char* path, char* file, mode_t mode, const FXbool dironly, cons
     struct stat linfo;
 
     // Initialize the file variable with the initial path
-    strlcpy(file, path, strlen(path) + 1);
+    strlcpy_(file, path, strlen(path) + 1);
 
     // If it doesn't exist
     if (lstatrep(path, &linfo))
@@ -1747,15 +1746,15 @@ int File::rchmod(char* path, char* file, mode_t mode, const FXbool dironly, cons
             int pl1 = pl, l = strlen(entry->d_name);
             char* path1 = (char*)alloca(pl1 + l + 2);
 
-            strlcpy(path1, path, strlen(path) + 1);
+            strlcpy_(path1, path, strlen(path) + 1);
             if (path1[pl1 - 1] != '/')
             {
                 path1[pl1++] = '/';
             }
-            strlcpy(path1 + pl1, entry->d_name, strlen(entry->d_name) + 1);
+            strlcpy_(path1 + pl1, entry->d_name, strlen(entry->d_name) + 1);
 
             // Modify the file variable with the new path
-            strlcpy(file, path1, strlen(path1) + 1);
+            strlcpy_(file, path1, strlen(path1) + 1);
             if (rchmod(path1, file, mode, dironly, fileonly))
             {
                 closedir(dir);
@@ -1791,7 +1790,7 @@ int File::chown(char* path, char* file, uid_t uid, gid_t gid, const FXbool rec,
     struct stat linfo;
 
     // Initialise the file variable with the initial path
-    strlcpy(file, path, strlen(path) + 1);
+    strlcpy_(file, path, strlen(path) + 1);
 
     // If it doesn't exist
     if (lstatrep(path, &linfo))
@@ -1880,7 +1879,7 @@ int File::rchown(char* path, char* file, uid_t uid, gid_t gid, const FXbool diro
     struct stat linfo;
 
     // Initialise the file variable with the initial path
-    strlcpy(file, path, strlen(path) + 1);
+    strlcpy_(file, path, strlen(path) + 1);
 
     // If it doesn't exist
     if (lstatrep(path, &linfo))
@@ -1938,13 +1937,13 @@ int File::rchown(char* path, char* file, uid_t uid, gid_t gid, const FXbool diro
             int pl1 = pl, l = strlen(entry->d_name);
             char* path1 = (char*)alloca(pl1 + l + 2);
 
-            strlcpy(path1, path, strlen(path) + 1);
+            strlcpy_(path1, path, strlen(path) + 1);
             if (path1[pl1 - 1] != '/')
             {
                 path1[pl1++] = '/';
             }
-            strlcpy(path1 + pl1, entry->d_name, strlen(entry->d_name) + 1);
-            strlcpy(file, path1, strlen(path1) + 1);
+            strlcpy_(path1 + pl1, entry->d_name, strlen(entry->d_name) + 1);
+            strlcpy_(file, path1, strlen(path1) + 1);
             if (rchown(path1, file, uid, gid, dironly, fileonly))
             {
                 closedir(dir);
