@@ -152,7 +152,7 @@ FontSelector::FontSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
     preview->setBackColor(getApp()->getBackColor());
 
     FXString fontname = FXString(DEFAULT_NORMAL_FONT);
-    strlcpy(selected.face, fontname.before(',').text(), sizeof(selected.face) + 1);
+    strlcpy_(selected.face, fontname.before(',').text(), sizeof(selected.face) + 1);
     selected.size = 90;
     selected.weight = FXFont::Bold;
     selected.slant = 0;
@@ -203,7 +203,7 @@ void FontSelector::listFontFaces()
             familylist->setCurrentItem(selindex);
             familylist->makeItemVisible(selindex);
             family->setText(familylist->getItemText(selindex));
-            strlcpy(selected.face, familylist->getItemText(selindex).text(), sizeof(selected.face) + 1);
+            strlcpy_(selected.face, familylist->getItemText(selindex).text(), sizeof(selected.face) + 1);
         }
         FXFREE(&fonts);
     }
@@ -464,7 +464,7 @@ void FontSelector::previewFont()
 // Selected font family
 long FontSelector::onCmdFamily(FXObject*, FXSelector, void* ptr)
 {
-    strlcpy(selected.face, familylist->getItemText((int)(FXival)ptr).text(), sizeof(selected.face) + 1);
+    strlcpy_(selected.face, familylist->getItemText((int)(FXival)ptr).text(), sizeof(selected.face) + 1);
     family->setText(selected.face);
     listWeights();
     listSlants();
