@@ -247,6 +247,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
     extension = file.rafter('.', 1).lower();
     if ((extension == "gz") || (extension == "tgz") || (extension == "tar") || (extension == "taz") || (extension == "bz2") ||
         (extension == "tbz2") || (extension == "tbz") || (extension == "xz") || (extension == "txz") || (extension == "zip") ||
+        (extension == "tzst") || (extension == "zst") || 
         (extension == "7z") || (extension == "Z") || (extension == "lzh") || (extension == "rar") ||
         (extension == "ace") || (extension == "arj"))
     {
@@ -379,7 +380,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
                         isMountpoint = true;
                         snprintf(buf, sizeof(buf) - 1, _("Filesystem (%s)"), mnt->mnt_fsname);
                         type = buf;
-                        strlcpy(mnttype, mnt->mnt_type, strlen(mnt->mnt_type) + 1);
+                        strlcpy_(mnttype, mnt->mnt_type, strlen(mnt->mnt_type) + 1);
                     }
                 }
             }
@@ -407,17 +408,17 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
                 strtok(NULL, " ");
                 char* pstr;
                 pstr = strtok(NULL, " ");
-                strlcpy(used, pstr, strlen(pstr) + 1);  // get used
+                strlcpy_(used, pstr, strlen(pstr) + 1);  // get used
                 pstr = strtok(NULL, " ");
-                strlcpy(avail, pstr, strlen(pstr) + 1); // get available
+                strlcpy_(avail, pstr, strlen(pstr) + 1); // get available
                 pstr = strtok(NULL, " ");
-                strlcpy(pctr, pstr, strlen(pstr) + 1);  // get percentage
+                strlcpy_(pctr, pstr, strlen(pstr) + 1);  // get percentage
             }
             else
             {
-                strlcpy(used, "", 1);
-                strlcpy(avail, "", 1);
-                strlcpy(pctr, "", 1);
+                strlcpy_(used, "", 1);
+                strlcpy_(avail, "", 1);
+                strlcpy_(pctr, "", 1);
             }
             pclose(p);
         }
@@ -452,7 +453,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
     {
         // Try to use association table
         extension2 = FXPath::name(pathname).rafter('.', 2).lower();
-        if ((extension2 == "tar.gz") || (extension2 == "tar.bz2") || (extension2 == "tar.xz") || (extension2 == "tar.z"))
+        if ((extension2 == "tar.gz") || (extension2 == "tar.bz2") || (extension2 == "tar.xz") || (extension2 == "tar.zst") || (extension2 == "tar.z"))
         {
             extension = extension2;
         }
@@ -556,7 +557,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path) : Dial
             {
                 // Try to use association table
                 extension2 = FXPath::name(referredpath).rafter('.', 2).lower();
-                if ((extension2 == "tar.gz") || (extension2 == "tar.bz2") || (extension2 == "tar.xz") || (extension2 == "tar.z"))
+                if ((extension2 == "tar.gz") || (extension2 == "tar.bz2") || (extension2 == "tar.xz") || (extension2 == "tar.zst") || (extension2 == "tar.z"))
                 {
                     extension = extension2;
                 }
@@ -1049,7 +1050,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString* file, int n, FXString* pat
 
             // Try to use association table
             extension2 = files[i].rafter('.', 2).lower();
-            if ((extension2 == "tar.gz") || (extension2 == "tar.bz2") || (extension2 == "tar.xz") || (extension2 == "tar.z"))
+            if ((extension2 == "tar.gz") || (extension2 == "tar.bz2") || (extension2 == "tar.xz") || (extension2 == "tar.zst") || (extension2 == "tar.z"))
             {
                 extension = extension2;
             }
@@ -1389,8 +1390,8 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o, FXSelector s, void* p)
                 str = new char* [2];
                 str[0] = new char[strlen(ext->getText().text()) + 1];
                 str[1] = new char[strlen(command.text()) + 1];
-                strlcpy(str[0], ext->getText().text(), ext->getText().length() + 1);
-                strlcpy(str[1], command.text(), command.length() + 1);
+                strlcpy_(str[0], ext->getText().text(), ext->getText().length() + 1);
+                strlcpy_(str[1], command.text(), command.length() + 1);
                 mainWindow->handle(this, FXSEL(SEL_COMMAND, XFileExplorer::ID_FILE_ASSOC), str);
             }
         }
@@ -2205,7 +2206,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o, FXSelector s, void* p)
                 FXulong dirsize = 0;
 
                 FXString dirpath = FXPath::absolute(parentdir, filename);
-                strlcpy(buf, dirpath.text(), dirpath.length() + 1);
+                strlcpy_(buf, dirpath.text(), dirpath.length() + 1);
 
                 // Open pipes to communicate with child process
                 if (pipe(pipes) == -1)
@@ -2287,7 +2288,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o, FXSelector s, void* p)
                     isDirectory = S_ISDIR(info.st_mode);
                     if (isDirectory)
                     {
-                        strlcpy(buf, pathname.text(), pathname.length() + 1);
+                        strlcpy_(buf, pathname.text(), pathname.length() + 1);
 
                         if (totalnbsubdirs > 0)
                         {
@@ -2298,7 +2299,7 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o, FXSelector s, void* p)
                     }
                     else           // Regular file
                     {
-                        strlcpy(buf, pathname.text(), pathname.length() + 1);
+                        strlcpy_(buf, pathname.text(), pathname.length() + 1);
                         pathsize(buf, &totalnbfiles, &totalnbsubdirs, &totaldirsize, pipes);
                     }
                 }
