@@ -868,11 +868,6 @@ XFileImage::XFileImage(FXApp* a, FXbool smoothscroll) : FXMainWindow(a, "Xfi ",
     // Initialize previous window width / height
     prev_width = getWidth();
     prev_height = getHeight();
-    
-    delete btn;
-    delete mc;
-    delete sep1;
-    delete sep2;
 }
 
 
