@@ -530,7 +530,7 @@ int XFilePackage::readFileList(void)
     char text[10000] = { 0 };
     FXString str;
     str = FXPath::name(filename);
-    strlcpy(text, str.text(), str.length() + 1);
+    strlcpy_(text, str.text(), str.length() + 1);
 
     // Clear list
     list->clearItems();
