@@ -15,7 +15,7 @@
 
 FXIcon *archaddicon, *archexticon, *attribicon, *bigattribicon, *bigblockdevicon, *bigbrokenlinkicon, *bigcdromicon, *bigchardevicon;
 FXIcon *bigcompareicon, *bigdocicon, *bigexecicon, *bigfileopenicon, *bigfiltericon, *bigfloppyicon, *bigfolderlockedicon;
-FXIcon *bigfolderopenicon, *bigfoldericon, *bigfolderupicon, *bigharddiskicon, *bigiconsicon, *biglinkicon, *bignewfileicon;
+FXIcon *bigfolderopenicon, *bigfoldericon, *bigfolderlinkicon, *bigfolderupicon, *bigharddiskicon, *bigiconsicon, *biglinkicon, *bignewfileicon;
 FXIcon *bignewfoldericon, *bignewlinkicon, *bignfsdriveicon;
 FXIcon *bignfsdriveumticon, *bigpipeicon, *bigsocketicon, *bigzipicon, *cdromicon, *charticon;
 FXIcon *closefileicon, *clrbookicon, *collfoldericon, *copy_bigicon, *colltreeicon;
@@ -27,7 +27,7 @@ FXIcon *fontsicon, *gotobigicon, *gotodiricon, *gotolineicon, *harddiskicon, *he
 FXIcon *hidenumbersicon, *hidethumbicon, *homeicon, *infobigicon, *invselicon, *link_bigicon;
 FXIcon *locationicon, *lowercaseicon, *maphosticon, *miniappicon, *miniblockdevicon, *minibrokenlinkicon;
 FXIcon *minichardevicon, *minidocicon, *miniexecicon, *minifolderclosedicon;
-FXIcon *minifolderlockedicon, *minifolderopenicon, *minifoldericon, *minifolderupicon, *minilinkicon;
+FXIcon *minifolderlockedicon, *minifolderopenicon, *minifoldericon, *minifolderlinkicon, *minifolderupicon, *minilinkicon;
 FXIcon *minipipeicon, *minishellicon, *minisocketicon;
 FXIcon *move_bigicon, *moveiticon, *newfileicon, *newfoldericon, *nfsdriveicon, *nfsdriveumticon;
 FXIcon *onepanelicon, *packageicon, *paste_clpicon, *prefsicon, *printbigicon, *printicon;
@@ -77,6 +77,7 @@ FXbool loadAppIcons(FXApp* app, FXbool *iconpathfound)
     success = ((bigfolderlockedicon = loadiconfile(app, iconpath, "bigfolderlocked.png")) != NULL) & success;
     success = ((bigfolderopenicon = loadiconfile(app, iconpath, "bigfolderopen.png")) != NULL) & success;
     success = ((bigfoldericon = loadiconfile(app, iconpath, "bigfolder.png")) != NULL) & success;
+    success = ((bigfolderlinkicon = loadiconfile(app, iconpath, "bigfolderlink.png")) != NULL) & success;
     success = ((bigfolderupicon = loadiconfile(app, iconpath, "bigfolderup.png")) != NULL) & success;
     success = ((bigharddiskicon = loadiconfile(app, iconpath, "bigharddisk.png")) != NULL) & success;
     success = ((bigiconsicon = loadiconfile(app, iconpath, "bigicons.png")) != NULL) & success;
@@ -142,6 +143,7 @@ FXbool loadAppIcons(FXApp* app, FXbool *iconpathfound)
     success = ((minifolderlockedicon = loadiconfile(app, iconpath, "minifolderlocked.png")) != NULL) & success;
     success = ((minifolderopenicon = loadiconfile(app, iconpath, "minifolderopen.png")) != NULL) & success;
     success = ((minifoldericon = loadiconfile(app, iconpath, "minifolder.png")) != NULL) & success;
+    success = ((minifolderlinkicon = loadiconfile(app, iconpath, "minifolderlink.png")) != NULL) & success;
     success = ((minifolderupicon = loadiconfile(app, iconpath, "minifolderup.png")) != NULL) & success;
     success = ((minilinkicon = loadiconfile(app, iconpath, "minilink.png")) != NULL) & success;
     success = ((minipipeicon = loadiconfile(app, iconpath, "minipipe.png")) != NULL) & success;
