@@ -705,11 +705,10 @@ FXbool isUtf8(const char* string, FXuint length)
 }
 
 
-#if !defined (__OpenBSD__)
 // Safe strcpy function (Public domain, by C.B. Falconer)
 // The destination string is always null terminated
 // Size sz must be equal to strlen(src)+1
-size_t strlcpy(char* dst, const char* src, size_t sz)
+size_t strlcpy_(char* dst, const char* src, size_t sz)
 {
     const char* start = src;
 
@@ -745,7 +744,7 @@ size_t strlcpy(char* dst, const char* src, size_t sz)
 
 // Safe strcat function (Public domain, by C.B. Falconer)
 // The destination string is always null terminated
-size_t strlcat(char* dst, const char* src, size_t sz)
+size_t strlcat_(char* dst, const char* src, size_t sz)
 {
     char* start = dst;
 
@@ -753,13 +752,13 @@ size_t strlcat(char* dst, const char* src, size_t sz)
     {
         if (sz)
         {
-            sz--;          // i.e. well formed string
+            sz--;       // i.e. well formed string
         }
     }
     dst--;
-    return(dst - start + strlcpy(dst, src, sz));
+    return(dst - start + strlcpy_(dst, src, sz));
 }
-#endif
+
 
 // Obtain the non recursive size of a directory
 FXulong dirsize(const char* path)
@@ -889,7 +888,7 @@ FXulong pathsize(char* path, FXuint* nbfiles, FXuint* nbsubdirs, FXulong *totals
         {
             continue;
         }
-        strlcpy(ptr, dirp->d_name, strlen(dirp->d_name) + 1);
+        strlcpy_(ptr, dirp->d_name, strlen(dirp->d_name) + 1);
 
         // Recursive call
         dsize += pathsize(path, nbfiles, nbsubdirs, totalsize, pipes);
@@ -918,23 +917,23 @@ FXString hSize(char* size)
     FXulong lsize = strtoull(size, NULL, 10);
     float fsize = 0.0;
 
-    strlcpy(suf, _("bytes"), sizeof(suf));
+    strlcpy_(suf, _("bytes"), sizeof(suf));
     if (lsize > 1e9)
     {
         fsize = lsize / 1e9;
-        strlcpy(suf, _("GB"), sizeof(suf));
+        strlcpy_(suf, _("GB"), sizeof(suf));
         flag = 1;
     }
     else if (lsize > 1e6)
     {
         fsize = lsize / 1e6;
-        strlcpy(suf, _("MB"), sizeof(suf));
+        strlcpy_(suf, _("MB"), sizeof(suf));
         flag = 1;
     }
     else if (lsize > 1e3)
     {
         fsize = lsize / 1e3;
-        strlcpy(suf, _("kB"), sizeof(suf));
+        strlcpy_(suf, _("kB"), sizeof(suf));
         flag = 1;
     }
 
@@ -1642,13 +1641,13 @@ int runst(FXString cmd)
             j += 2;
             i += str2.contains(' ');
             args[nbargs] = (char*)malloc(str2.length() + 1);
-            strlcpy(args[nbargs], str2.text(), str2.length() + 1);
+            strlcpy_(args[nbargs], str2.text(), str2.length() + 1);
             nbargs++;
         }
         else
         {
             args[nbargs] = (char*)malloc(str1.length() + 1);
-            strlcpy(args[nbargs], str1.text(), str1.length() + 1);
+            strlcpy_(args[nbargs], str1.text(), str1.length() + 1);
             nbargs++;
         }
 
