@@ -639,10 +639,8 @@ FXString mimetype(FXString);
 FXString quote(FXString);
 FXbool isUtf8(const char*, FXuint);
 
-#if !defined (__OpenBSD__)
-size_t strlcpy(char*, const char*, size_t);
-size_t strlcat(char*, const char*, size_t);
-#endif
+size_t strlcpy_(char*, const char*, size_t);
+size_t strlcat_(char*, const char*, size_t);
 
 FXulong dirsize(const char*);
 FXulong pathsize(char*, FXuint*, FXuint*, FXulong*, int* = NULL);
